# ellar_storage_tut
A Quick illustration of how to use ellar-storage for any local/cloud file storage.

## Requirements
Python >= 3.8
ellar

## Project setup
```
pip install -r requirements.txt
```

### Development Server
```
python manage.py runserver --reload
```

Visit [http://localhost:8000/docs](http://localhost:8000/docs)